pub struct Restriction {
pub marketplace_id: String,
pub condition_type: Option<ConditionType>,
pub reasons: Option<Vec<Reason>>,
}Expand description
Restriction : A listing restriction, optionally qualified by a condition, with a list of reasons for the restriction.
Fields
marketplace_id: StringA marketplace identifier. Identifies the Amazon marketplace where the restriction is enforced.
condition_type: Option<ConditionType>The condition that applies to the restriction.
reasons: Option<Vec<Reason>>A list of reasons for the restriction.
Implementations
sourceimpl Restriction
impl Restriction
sourcepub fn new(marketplace_id: String) -> Restriction
pub fn new(marketplace_id: String) -> Restriction
A listing restriction, optionally qualified by a condition, with a list of reasons for the restriction.